@@ -256,12 +256,16 @@ def main(syn, challenge_name, live_site=None):
                    id. (Default is None)
 
     Returns:
-        dict: {"live_projectid": projectid,
-               "staging_projectid": projectid,
-               "admin_teamid": teams['team_admin_id'],
-               "organizer_teamid": teams['team_org_id'],
-               "participant_teamid": teams['team_part_id'],
-               "preregistrantrant_teamid": teams['team_prereg_id']}
+        dict::
+
+            {
+                "live_projectid": projectid,
+                "staging_projectid": projectid,
+                "admin_teamid": teams['team_admin_id'],
+                "organizer_teamid": teams['team_org_id'],
+                "participant_teamid": teams['team_part_id'],
+                "preregistrantrant_teamid": teams['team_prereg_id']
+            }
 
     """
     # Create teams for challenge sites
